@@ -1,5 +1,5 @@
 -- | <https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/>
-{-# LANGUAGE CPP, DeriveDataTypeable, FlexibleInstances, OverloadedStrings, ScopedTypeVariables, TemplateHaskell, TupleSections, LambdaCase #-}
+{-# LANGUAGE DeriveDataTypeable, FlexibleInstances, OverloadedStrings, ScopedTypeVariables, TemplateHaskell, TupleSections, LambdaCase #-}
 module Debian.Debianize.CopyrightDescription
     ( CopyrightDescription(..)
     , FilesOrLicenseDescription(..)
@@ -44,26 +44,14 @@ import Debian.Pretty (prettyText, ppText)
 import Debug.Trace
 import qualified Distribution.License as Cabal (License(UnknownLicense))
 import qualified Distribution.Package as Cabal
-#if MIN_VERSION_Cabal(2,2,0)
 import qualified Distribution.PackageDescription as Cabal (PackageDescription(licenseFiles, copyright, licenseRaw, package, maintainer))
-#else
-#if MIN_VERSION_Cabal(1,20,0)
-import qualified Distribution.PackageDescription as Cabal (PackageDescription(licenseFiles, copyright, license, package, maintainer))
-#else
-import qualified Distribution.PackageDescription as Cabal (PackageDescription(licenseFile, copyright, license, package, maintainer))
-#endif
-#endif
 import Network.URI (URI, parseURI)
 import Prelude hiding (init, init, log, log, unlines, readFile)
 import Text.PrettyPrint.HughesPJClass (text)
 import Distribution.Pretty (Pretty(pretty))
 
 unPackageName :: Cabal.PackageName -> String
-#if MIN_VERSION_Cabal(2,0,0)
 unPackageName p = Cabal.unPackageName p
-#else
-unPackageName (Cabal.PackageName x) = x
-#endif
 
 -- | Description of the machine readable debian/copyright file.  A
 -- special case is used to represeent the old style free format file -
@@ -242,11 +230,7 @@ defaultLicenseDescriptions license = \case
   where
     mkLicenseDescription (path, txt) =
       LicenseDescription {
-#if MIN_VERSION_Cabal(2,2,0)
           _license = fromCabalLicense (Cabal.UnknownLicense path)
-#else
-          _license = fromCabalLicense (Cabal.UnknownLicense path)
-#endif
         , _licenseText = txt
         , _comment = mempty
         }
@@ -258,16 +242,8 @@ defaultLicenseDescriptions license = \case
 -- provided @copyright0@ value.
 defaultCopyrightDescription :: Cabal.PackageDescription -> IO CopyrightDescription
 defaultCopyrightDescription pkgDesc = do
-#if MIN_VERSION_Cabal(1,20,0)
   let (debianCopyrightPath, otherLicensePaths) = partition (== "debian/copyright") (Cabal.licenseFiles pkgDesc)
-#else
-  let (debianCopyrightPath, otherLicensePaths) = partition (== "debian/copyright") [Cabal.licenseFile pkgDesc]
-#endif
-#if MIN_VERSION_Cabal(2,2,0)
       license =  either (\x -> OtherLicense ("SPDX license: " ++ show x)) fromCabalLicense $ Cabal.licenseRaw pkgDesc
-#else
-      license = fromCabalLicense $ Cabal.license pkgDesc
-#endif
       pkgname = unPackageName . Cabal.pkgName . Cabal.package $ pkgDesc
       maintainer = Cabal.maintainer $ pkgDesc
   -- This is an @Nothing@ unless debian/copyright is (for some
