@@ -1,5 +1,5 @@
 -- | Read an existing Debianization from a directory file.
-{-# LANGUAGE CPP, DeriveDataTypeable, FlexibleInstances, ScopedTypeVariables, TypeSynonymInstances #-}
+{-# LANGUAGE DeriveDataTypeable, FlexibleInstances, ScopedTypeVariables, TypeSynonymInstances #-}
 {-# OPTIONS_GHC -Wall -fno-warn-orphans #-}
 module Debian.Debianize.InputDebian
     ( inputDebianization
@@ -19,9 +19,6 @@ import Data.Char (isSpace)
 import Data.Map as Map (insert, insertWith)
 import Data.Maybe (fromMaybe)
 import Data.Monoid ((<>))
-#if !MIN_VERSION_base(4,8,0)
-import Data.Monoid (mappend)
-#endif
 import Data.Set as Set (fromList, insert, singleton)
 import Data.Text (break, lines, null, pack, strip, Text, unpack, words)
 import Data.Text.IO (readFile)
@@ -40,11 +37,7 @@ import Debian.Orphans ()
 import Debian.Policy (parseMaintainer, parsePackageArchitectures, parseStandardsVersion, parseUploaders, readPriority, readSection, readMultiArch, readSourceFormat, Section(..))
 import Debian.Relation (BinPkgName(..), parseRelations, Relations, SrcPkgName(..))
 --import Debug.Trace (trace)
-#if MIN_VERSION_Cabal(2,0,0)
 import Distribution.Package (PackageIdentifier(..), unPackageName)
-#else
-import Distribution.Package (PackageIdentifier(..), PackageName(..))
-#endif
 import qualified Distribution.PackageDescription as Cabal (dataDir, PackageDescription(package))
 import Prelude hiding (break, lines, log, null, readFile, sum, words)
 import System.Directory (doesFileExist)
@@ -300,12 +293,7 @@ readDir p line = installDir p (unpack line)
 dataDest :: Monad m => CabalT m FilePath
 dataDest = do
   d <- use packageDescription
-#if MIN_VERSION_Cabal(2,0,0)
   return $ "usr/share" </> (unPackageName $ pkgName $ Cabal.package d)
-#else
-  return $ "usr/share" </> ((\ (PackageName x) -> x) $ pkgName $ Cabal.package d)
-
-#endif
 -- | Where to look for the data-files
 dataTop :: Monad m => CabalT m FilePath
 dataTop = do
