@@ -1,6 +1,6 @@
 -- | Code pulled out of cabal-debian that straightforwardly implements
 -- parts of the Debian policy manual, or other bits of Linux standards.
-{-# LANGUAGE CPP, DeriveDataTypeable, FlexibleInstances, OverloadedStrings #-}
+{-# LANGUAGE DeriveDataTypeable, FlexibleInstances, OverloadedStrings #-}
 module Debian.Policy
     ( -- * Paths
       databaseDirectory
@@ -64,11 +64,7 @@ import System.Environment (getEnvironment)
 import System.FilePath ((</>))
 import System.Process (readProcess)
 import Text.Parsec (parse)
-#if MIN_VERSION_hsemail(2,0,0)
 import Text.Parsec.Rfc2822 (address, NameAddr(..))
-#else
-import Text.ParserCombinators.Parsec.Rfc2822 (address, NameAddr(..))
-#endif
 import Text.PrettyPrint.HughesPJClass (text)
 import Distribution.Pretty (Pretty(pretty))
 import Text.Read (readMaybe)
@@ -402,20 +398,16 @@ fromCabalLicense x =
       Cabal.LGPL _ -> LGPL
       Cabal.BSD3 -> BSD_3_Clause
       Cabal.BSD4 -> BSD_4_Clause
-      Cabal.MIT -> OtherLicense (show x)
+      Cabal.MIT -> Expat
       Cabal.Apache _ -> Apache
       Cabal.PublicDomain -> Public_Domain
       Cabal.AllRightsReserved -> OtherLicense "AllRightsReserved"
       Cabal.OtherLicense -> OtherLicense (show x)
       Cabal.UnknownLicense _ -> OtherLicense (show x)
-#if MIN_VERSION_Cabal(1,20,0)
       Cabal.MPL _ -> MPL
-#if MIN_VERSION_Cabal(1,22,0)
       Cabal.BSD2 -> BSD_2_Clause
       Cabal.ISC -> OtherLicense (show x)
       Cabal.UnspecifiedLicense -> OtherLicense (show x)
-#endif
-#endif
 
 -- | Convert a Debian license to a Cabal license.  Additional cases
 -- and corrections welcome.
@@ -423,11 +415,10 @@ toCabalLicense :: License -> Cabal.License
 toCabalLicense x =
     -- This needs to be finished
     case x of
-#if MIN_VERSION_Cabal(1,22,0)
       BSD_2_Clause -> Cabal.BSD2
-#endif
       BSD_3_Clause -> Cabal.BSD3
       BSD_4_Clause -> Cabal.BSD4
+      Expat -> Cabal.MIT
       OtherLicense s -> Cabal.UnknownLicense s
       _ -> Cabal.UnknownLicense (show x)
 
